"""
A library for creating Learning Python Algorithms files.
"""

from .algorithm import AlgorithmDemo
from ._version import get_versions

__version__ = get_versions()['version']
del get_versions

__doc__ = """
chameleon - 这是一个学习 Python 算法 强大工具库
=====================================================================
介绍：
------
1. 可以通过该工具直接学习算法，有相关的算法示例，可以很好的掌握 Python 算法，提高编程逻辑
2. 开发时间：2021-5-20。
3. 版本号：0.1.15。

"""



import setuptools
setuptools.setup(
    name="testchameleon",
    version="1.0",
    description="this is a module made by kevin",
    author="jiaxing",
    py_modules=["testchameleon._version", "testchameleon.algorithm"]
)



# !/usr/bin/python3 
# -*- coding: utf-8 -*-

class AlgorithmDemo(object):

    def __init__(self):
        pass

    def demo_one(self):
        """
        冒泡排序用法
        :return:
        """
        data = [32,25,95,68,12,73,65]
        for i in range(len(data) - 1):
            for j in range(len(data) - i - 1):
                if data[j] > data[j + 1]:
                    data[j], data[j + 1] = data[j + 1], data[j]
        return data

    def demo_two(self):
        pass


class RunDemo(AlgorithmDemo):

    def run_one(self):
        demo = self.demo_one()
        return demo

    def run_two(self):
        pass
